Feature class

Annotations
  • @freezed

Constructors

Feature({@JsonKey.new(name: 'key') @Default.new('') String key, @JsonKey.new(name: 'boolean') @Default.new(false) bool boolValue, @JsonKey.new(name: 'string') @Default.new('') String stringValue})
const
factory
Feature.fromJson(Map<String, dynamic> json)
factory

Properties

boolValue bool
no setterinherited
copyWith → $FeatureCopyWith<Feature>
Create a copy of Feature with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
key String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringValue String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Feature to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited